## CryptoMongoModel
Contains the model and data access methods  for cryptos and coimarketcap  stores in mongo db

#### to package 
https://packaging.python.org/tutorials/packaging-projects/


#### to use 
pip install -i https://test.pypi.org/simple/CryptoModel-athanikos==0.0.1













